==> kubernetes-model-1.0.20-sources.jar: annotations/io/fabric8/kubernetes/api/model/GlusterfsVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class GlusterfsVolumeSourceBuilder extends GlusterfsVolumeSourceFluent<GlusterfsVolumeSourceBuilder> implements VisitableBuilder<GlusterfsVolumeSource,GlusterfsVolumeSourceBuilder>{

     GlusterfsVolumeSourceFluent<?> fluent;
public GlusterfsVolumeSourceBuilder(){
    this(new GlusterfsVolumeSource());
}
public GlusterfsVolumeSourceBuilder( GlusterfsVolumeSourceFluent<?> fluent ){
    this(fluent, new GlusterfsVolumeSource());
}
public GlusterfsVolumeSourceBuilder( GlusterfsVolumeSourceFluent<?> fluent , GlusterfsVolumeSource instance ){
    this.fluent = fluent; fluent.withEndpoints(instance.getEndpoints()); fluent.withPath(instance.getPath()); fluent.withReadOnly(instance.getReadOnly()); 
}
public GlusterfsVolumeSourceBuilder( GlusterfsVolumeSource instance ){
    this.fluent = this; this.withEndpoints(instance.getEndpoints()); this.withPath(instance.getPath()); this.withReadOnly(instance.getReadOnly()); 
}

public EditableGlusterfsVolumeSource build(){
    EditableGlusterfsVolumeSource buildable = new EditableGlusterfsVolumeSource(fluent.getEndpoints(),fluent.getPath(),fluent.isReadOnly());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
GlusterfsVolumeSourceBuilder that = (GlusterfsVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.37-sources.jar: annotations/io/fabric8/kubernetes/api/model/GlusterfsVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class GlusterfsVolumeSourceBuilder extends GlusterfsVolumeSourceFluentImpl<GlusterfsVolumeSourceBuilder> implements VisitableBuilder<GlusterfsVolumeSource,GlusterfsVolumeSourceBuilder>{

     GlusterfsVolumeSourceFluent<?> fluent;
public GlusterfsVolumeSourceBuilder(){
    this(new GlusterfsVolumeSource());
}
public GlusterfsVolumeSourceBuilder( GlusterfsVolumeSourceFluent<?> fluent ){
    this(fluent, new GlusterfsVolumeSource());
}
public GlusterfsVolumeSourceBuilder( GlusterfsVolumeSourceFluent<?> fluent , GlusterfsVolumeSource instance ){
    this.fluent = fluent; fluent.withEndpoints(instance.getEndpoints()); fluent.withPath(instance.getPath()); fluent.withReadOnly(instance.getReadOnly()); 
}
public GlusterfsVolumeSourceBuilder( GlusterfsVolumeSource instance ){
    this.fluent = this; this.withEndpoints(instance.getEndpoints()); this.withPath(instance.getPath()); this.withReadOnly(instance.getReadOnly()); 
}

public EditableGlusterfsVolumeSource build(){
    EditableGlusterfsVolumeSource buildable = new EditableGlusterfsVolumeSource(fluent.getEndpoints(),fluent.getPath(),fluent.isReadOnly());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
GlusterfsVolumeSourceBuilder that = (GlusterfsVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
